ReportBlock class

One row of an SR/RR report block (6.4.1).

Constructors

ReportBlock({required int ssrc, required int fractionLost, required int cumulativeLost, required int extendedHighestSeq, required int jitter, required int lastSr, required int delaySinceLastSr})
const

Properties

cumulativeLost int
24-bit signed cumulative number of packets lost.
final
delaySinceLastSr int
Delay since last SR, in 1/65536 second units (or 0).
final
extendedHighestSeq int
Extended highest sequence number received (high 16 = cycles).
final
fractionLost int
8-bit fraction of packets lost since the previous SR/RR.
final
hashCode int
The hash code for this object.
no setterinherited
jitter int
Inter-arrival jitter, in RTP timestamp units.
final
lastSr int
Middle 32 bits of the last SR's NTP timestamp (or 0).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ssrc int
SSRC of the source this block describes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(ByteData bd, int offset) ReportBlock