SourceDescription class

SDES packet (PT=202) carrying one chunk (CNAME).

Constructors

SourceDescription({required List<SdesChunk> chunks})
const

Properties

chunks List<SdesChunk>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited