RtpPacket class

Decoded inbound RTP packet.

Constructors

RtpPacket({required int payloadType, required int sequenceNumber, required int timestamp, required int ssrc, required Uint8List payload, required bool marker})

Properties

hashCode int
The hash code for this object.
no setterinherited
marker bool
final
payload Uint8List
final
payloadType int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sequenceNumber int
final
ssrc int
final
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited