RtpState class

Mutable per-stream state. One instance per outbound RTP stream.

Constructors

RtpState({required int ssrc, required int payloadType, int? initialSequenceNumber})

Properties

hashCode int
The hash code for this object.
no setterinherited
payloadType int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seq int
getter/setter pair
ssrc int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited