DigestChallenge class

Constructors

DigestChallenge({required String realm, required String nonce, String? qop, String algorithm = 'MD5', String? opaque, bool stale = false})
DigestChallenge.fromParams(Map<String, String> p)
factory

Properties

algorithm String
final
hashCode int
The hash code for this object.
no setterinherited
nonce String
final
opaque String?
final
qop String?
final
realm String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stale bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited