SdpVideo class

Constructors

SdpVideo({required String host, required int port, required int payloadType, required SdpVideoCodec codec, int? rtcpPort, SdpDirection direction = SdpDirection.sendrecv})
const

Properties

codec SdpVideoCodec
final
direction SdpDirection
final
effectiveRtcpPort int
no setter
hashCode int
The hash code for this object.
no setterinherited
host String
final
payloadType int
Dynamic RTP payload type (96..127) negotiated for this codec.
final
port int
final
rtcpPort int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited