SdpVideoCodec enum
Video codecs we understand for SDP negotiation.
Values
- vp8 → const SdpVideoCodec
-
const SdpVideoCodec('VP8', 90000) - vp9 → const SdpVideoCodec
-
const SdpVideoCodec('VP9', 90000) - h264 → const SdpVideoCodec
-
const SdpVideoCodec('H264', 90000)
Properties
- clockRate → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - rtpmap → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SdpVideoCodec> - A constant List of the values in this enum, in order of their declaration.