SipMessage class

Constructors

SipMessage.parse(String raw)
Parse a wire message.
factory
SipMessage.request(String method, String requestUri, {List<MapEntry<String, String>>? headers, String body = ''})
Build a request.
factory
SipMessage.response({required int code, required String reason, List<MapEntry<String, String>>? headers, String body = ''})
Build a response.
factory

Properties

body String
getter/setter pair
callId String?
Returns the dialog identifier (Call-ID + local-tag + remote-tag).
no setter
cseq String?
Returns "
no setter
cseqMethod String?
no setter
cseqNumber int?
no setter
fromTag String?
no setter
hashCode int
The hash code for this object.
no setterinherited
headers List<MapEntry<String, String>>
final
isRequest bool
no setter
isResponse bool
no setter
method String?
final
reasonPhrase String?
final
requestUri String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
toTag String?
no setter

Methods

addHeader(String name, String value) → void
encode() String
Serialise back to the wire.
headersAll(String name) List<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeHeader(String name) → void
setHeader(String name, String value) → void
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited