SipTextMessage class

Constructors

SipTextMessage({required String from, required String body, required DateTime receivedAt, String to = '', bool outgoing = false})

Properties

body String
final
from String
final
hashCode int
The hash code for this object.
no setterinherited
outgoing bool
final
peer String
The remote party for this message regardless of direction. Useful when grouping messages into a per-buddy thread.
no setter
receivedAt DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited