EncodedVideoFrame class

Encoded compressed-video frame plus a hint of whether it's a key frame.

Constructors

EncodedVideoFrame({required Uint8List bytes, required bool keyFrame, required int timestamp})

Properties

bytes Uint8List
Raw bytestream for the codec (e.g. a VP8 frame).
final
hashCode int
The hash code for this object.
no setterinherited
keyFrame bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
90 kHz RTP timestamp.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited