VideoDecoder class abstract

Implementers

Constructors

VideoDecoder()

Properties

codec SdpVideoCodec
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
decode(Uint8List bytes) YuvFrame?
Decode one encoded frame and return the YUV picture, or null if the codec needs more data (e.g. the inbound stream hasn't seen a keyframe yet).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited