YuvFrame class

I420 (YUV 4:2:0) frame.

All three planes share the same image size; chroma planes are half-width, half-height. Strides default to plane width.

Constructors

YuvFrame({required int width, required int height, required Uint8List y, required Uint8List u, required Uint8List v, int? yStride, int? uStride, int? vStride})

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
u Uint8List
final
uStride int
final
v Uint8List
final
vStride int
final
width int
final
y Uint8List
final
yStride int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited