ReceiverReport class
Receiver Report (PT=201).
Constructors
-
ReceiverReport({required int ssrc, List<
ReportBlock> reports = const <ReportBlock>[]}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
reports
→ List<
ReportBlock> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ssrc → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
Uint8List data, int offset, int rc) → ReceiverReport