SdpAudio class
Constructors
- SdpAudio({required String host, required int port, required G711Variant codec, int? rtcpPort, SdpDirection direction = SdpDirection.sendrecv, int? telephoneEventPt, String? telephoneEventRange})
-
const
Properties
- codec → G711Variant
-
Negotiated G.711 variant.
final
- direction → SdpDirection
-
Direction (
a=sendrecvetc.). Defaults tosendrecvwhen absent.final - effectiveRtcpPort → int
-
Effective RTCP port (explicit if signalled, otherwise port + 1).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
Connection address from
c=.final - port → int
-
RTP port from
m=audio <port>.final - rtcpPort → int?
-
Explicit RTCP port from
a=rtcp:<port>. Null means RFC 3550 default (port + 1).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telephoneEventPt → int?
-
Payload type for
telephone-eventif the peer offered RFC 4733 DTMF.final - telephoneEventRange → String?
-
a=fmtp:<pt> <range>value paired with telephoneEventPt (e.g.0-15or0-16). Null when no fmtp line was present.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEndpoint(
) → RtpEndpoint -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited