AppTheme class
Centralised Material 3 theming for the app. Seed colour matches the InnovateAsterisk Browser-Phone accent (#3478F3) so light and dark schemes produce the same recognisable softphone look.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited