ui/widgets/call/call_buttons
library
Classes
-
BigCallButton
-
Big, branded answer/hangup button used at the bottom of the call
screen. Browser-Phone uses 76px rounded buttons with the dial green
or hangup red.
-
CallActionButton
-
Round 64-px control with a label underneath. The Browser-Phone
in-call action grid uses one of these per feature (Mute, Hold,
Keypad, Speaker, Transfer, Record, …).
-
Helper for the "extras" used during an active call but not part of
the always-visible action row (Transfer, Record, Add call, Stats).
Drawn as a horizontal scrollable strip so it never overflows.